@@ -53,6 +53,7 @@ sorted_classifiers: List[str] = [
     "Environment :: GPU :: NVIDIA CUDA :: 11.8",
     "Environment :: GPU :: NVIDIA CUDA :: 12",
     "Environment :: GPU :: NVIDIA CUDA :: 12 :: 12.0",
+    "Environment :: GPU :: NVIDIA CUDA :: 12 :: 12.1",
     "Environment :: Handhelds/PDA's",
     "Environment :: MacOS X",
     "Environment :: MacOS X :: Aqua",
@@ -120,6 +121,7 @@ sorted_classifiers: List[str] = [
     "Framework :: Django :: 4",
     "Framework :: Django :: 4.0",
     "Framework :: Django :: 4.1",
+    "Framework :: Django :: 4.2",
     "Framework :: Django CMS",
     "Framework :: Django CMS :: 3.4",
     "Framework :: Django CMS :: 3.5",
@@ -184,6 +186,7 @@ sorted_classifiers: List[str] = [
     "Framework :: Plone :: Core",
     "Framework :: Plone :: Distribution",
     "Framework :: Plone :: Theme",
+    "Framework :: Pycsou",
     "Framework :: Pydantic",
     "Framework :: Pydantic :: 1",
     "Framework :: Pylons",
@@ -210,6 +213,7 @@ sorted_classifiers: List[str] = [
     "Framework :: Wagtail :: 2",
     "Framework :: Wagtail :: 3",
     "Framework :: Wagtail :: 4",
+    "Framework :: Wagtail :: 5",
     "Framework :: ZODB",
     "Framework :: Zope",
     "Framework :: Zope2",
@@ -588,6 +592,9 @@ sorted_classifiers: List[str] = [
     "Topic :: Education",
     "Topic :: Education :: Computer Aided Instruction (CAI)",
     "Topic :: Education :: Testing",
+    "Topic :: File Formats",
+    "Topic :: File Formats :: JSON",
+    "Topic :: File Formats :: JSON :: JSON Schema",
     "Topic :: Games/Entertainment",
     "Topic :: Games/Entertainment :: Arcade",
     "Topic :: Games/Entertainment :: Board Games",
